@@ -36,7 +36,9 @@ import warnings
 
 class BaseResemblanceModel(BaseFitComputePlotClass):
     """
-    This model checks for similarity of two samples. A possible use case is analysis whether train sample differs
+    This model checks for similarity of two samples.
+
+    A possible use case is analysis whether train sample differs
         from test sample, due to e.g. non-stationarity.
 
     This is a base class and needs to be extended by a fit() method, which implements how data is split, how model is
@@ -61,7 +63,8 @@ class BaseResemblanceModel(BaseFitComputePlotClass):
 
             scoring (string or probatus.utils.Scorer, optional):
                 Metric for which the model performance is calculated. It can be either a metric name  aligned with
-                predefined [classification scorers names in sklearn](https://scikit-learn.org/stable/modules/model_evaluation.html).
+                predefined
+                [classification scorers names in sklearn](https://scikit-learn.org/stable/modules/model_evaluation.html).
                 Another option is using probatus.utils.Scorer to define a custom metric. Recommended option for this
                 class is 'roc_auc'.
 
@@ -83,7 +86,7 @@ class BaseResemblanceModel(BaseFitComputePlotClass):
                 Random state set at each round of feature elimination. If it is None, the results will not be
                 reproducible and in random search at each iteration a different hyperparameters might be tested. For
                 reproducible results set it to integer.
-        """
+        """  # noqa
         self.clf = clf
         self.test_prc = test_prc
         self.n_jobs = n_jobs
@@ -93,7 +96,7 @@ class BaseResemblanceModel(BaseFitComputePlotClass):
 
     def _init_output_variables(self):
         """
-        Initializes variables that will be filled in during fit() method, and are used as output
+        Initializes variables that will be filled in during fit() method, and are used as output.
         """
         self.X_train = None
         self.X_test = None
@@ -137,17 +140,11 @@ class BaseResemblanceModel(BaseFitComputePlotClass):
             self.class_names = ["First Sample", "Second Sample"]
 
         # Ensure inputs are correct
-        self.X1, self.column_names = preprocess_data(
-            X1, X_name="X1", column_names=column_names, verbose=self.verbose
-        )
-        self.X2, _ = preprocess_data(
-            X2, X_name="X2", column_names=column_names, verbose=self.verbose
-        )
+        self.X1, self.column_names = preprocess_data(X1, X_name="X1", column_names=column_names, verbose=self.verbose)
+        self.X2, _ = preprocess_data(X2, X_name="X2", column_names=column_names, verbose=self.verbose)
 
         # Prepare dataset for modelling
-        self.X = pd.DataFrame(
-            pd.concat([self.X1, self.X2], axis=0), columns=self.column_names
-        ).reset_index(drop=True)
+        self.X = pd.DataFrame(pd.concat([self.X1, self.X2], axis=0), columns=self.column_names).reset_index(drop=True)
 
         self.y = pd.Series(
             np.concatenate(
@@ -159,13 +156,9 @@ class BaseResemblanceModel(BaseFitComputePlotClass):
         ).reset_index(drop=True)
 
         # Assure the type and number of classes for the variable
-        self.X, _ = preprocess_data(
-            self.X, X_name="X", column_names=self.column_names, verbose=self.verbose
-        )
+        self.X, _ = preprocess_data(self.X, X_name="X", column_names=self.column_names, verbose=self.verbose)
 
-        self.y = preprocess_labels(
-            self.y, y_name="y", index=self.X.index, verbose=self.verbose
-        )
+        self.y = preprocess_labels(self.y, y_name="y", index=self.X.index, verbose=self.verbose)
 
         # Reinitialize variables in case of multiple times being fit
         self._init_output_variables()
@@ -180,12 +173,8 @@ class BaseResemblanceModel(BaseFitComputePlotClass):
         )
         self.clf.fit(self.X_train, self.y_train)
 
-        self.train_score = np.round(
-            self.scorer.score(self.clf, self.X_train, self.y_train), 3
-        )
-        self.test_score = np.round(
-            self.scorer.score(self.clf, self.X_test, self.y_test), 3
-        )
+        self.train_score = np.round(self.scorer.score(self.clf, self.X_train, self.y_train), 3)
+        self.test_score = np.round(self.scorer.score(self.clf, self.X_test, self.y_test), 3)
 
         self.results_text = (
             f"Train {self.scorer.metric_name}: {np.round(self.train_score, 3)},\n"
@@ -277,18 +266,21 @@ class BaseResemblanceModel(BaseFitComputePlotClass):
                 Depending on value of return_tuple either returns a tuple (feature importances, train AUC, test AUC), or
                 feature importances.
         """
-        self.fit(
-            X1, X2, column_names=column_names, class_names=class_names, **fit_kwargs
-        )
+        self.fit(X1, X2, column_names=column_names, class_names=class_names, **fit_kwargs)
         return self.compute(return_scores=return_scores)
 
     def plot(self):
+        """
+        Plot.
+        """
         raise (NotImplementedError("Plot method has not been implemented."))
 
 
 class PermutationImportanceResemblance(BaseResemblanceModel):
     """
-    This model checks for similarity of two samples. A possible use case is analysis whether train sample differs
+    This model checks for similarity of two samples.
+
+    A possible use case is analysis whether train sample differs
         from test sample, due to e.g. non-stationarity.
 
     It assigns to labels to each sample, 0 to first sample, 1 to the second. Then, It randomly selects a portion of
@@ -338,7 +330,8 @@ class PermutationImportanceResemblance(BaseResemblanceModel):
 
             scoring (string or probatus.utils.Scorer, optional):
                 Metric for which the model performance is calculated. It can be either a metric name  aligned with
-                predefined [classification scorers names in sklearn](https://scikit-learn.org/stable/modules/model_evaluation.html).
+                predefined
+                [classification scorers names in sklearn](https://scikit-learn.org/stable/modules/model_evaluation.html).
                 Another option is using probatus.utils.Scorer to define a custom metric. Recommended option for this
                 class is 'roc_auc'.
 
@@ -360,7 +353,7 @@ class PermutationImportanceResemblance(BaseResemblanceModel):
                 Random state set at each round of feature elimination. If it is None, the results will not be
                 reproducible and in random search at each iteration a different hyperparameters might be tested. For
                 reproducible results set it to integer.
-        """
+        """  # noqa
         super().__init__(
             clf=clf,
             scoring=scoring,
@@ -381,7 +374,9 @@ class PermutationImportanceResemblance(BaseResemblanceModel):
 
     def fit(self, X1, X2, column_names=None, class_names=None):
         """
-        This function assigns to labels to each sample, 0 to first sample, 1 to the second. Then, It randomly selects a
+        This function assigns to labels to each sample, 0 to first sample, 1 to the second.
+
+        Then, it randomly selects a
             portion of data to train on. The resulting model tries to distinguish which sample does a given test row
             comes from. This provides insights on how distinguishable these samples are and which features contribute to
             that. The feature importance is calculated using permutation importance.
@@ -419,40 +414,28 @@ class PermutationImportanceResemblance(BaseResemblanceModel):
 
         # Prepare report
         self.report_columns = ["mean_importance", "std_importance"]
-        self.report = pd.DataFrame(
-            index=self.column_names, columns=self.report_columns, dtype=float
-        )
+        self.report = pd.DataFrame(index=self.column_names, columns=self.report_columns, dtype=float)
 
         for feature_index, feature_name in enumerate(self.column_names):
             # Fill in the report
-            self.report.loc[feature_name, "mean_importance"] = permutation_result[
-                "importances_mean"
-            ][feature_index]
-            self.report.loc[feature_name, "std_importance"] = permutation_result[
-                "importances_std"
-            ][feature_index]
+            self.report.loc[feature_name, "mean_importance"] = permutation_result["importances_mean"][feature_index]
+            self.report.loc[feature_name, "std_importance"] = permutation_result["importances_std"][feature_index]
 
             # Fill in the iterations
             current_iterations = pd.DataFrame(
                 np.stack(
                     [
                         np.repeat(feature_name, self.iterations),
-                        permutation_result["importances"][feature_index, :].reshape(
-                            (self.iterations,)
-                        ),
+                        permutation_result["importances"][feature_index, :].reshape((self.iterations,)),
                     ],
                     axis=1,
                 ),
                 columns=self.iterations_columns,
             )
 
-            self.iterations_results = pd.concat(
-                [self.iterations_results, current_iterations]
-            )
+            self.iterations_results = pd.concat([self.iterations_results, current_iterations])
 
-        self.iterations_results["importance"] = self.iterations_results[
-            "importance"
-        ].astype(float)
+        self.iterations_results["importance"] = self.iterations_results["importance"].astype(float)
 
         # Sort by mean test score of first metric
         self.report.sort_values(by="mean_importance", ascending=False, inplace=True)
@@ -483,13 +466,9 @@ class PermutationImportanceResemblance(BaseResemblanceModel):
         """
 
         feature_report = self.compute()
-        self.iterations_results["importance"] = self.iterations_results[
-            "importance"
-        ].astype(float)
+        self.iterations_results["importance"] = self.iterations_results["importance"].astype(float)
 
-        sorted_features = (
-            feature_report["mean_importance"].sort_values(ascending=True).index.values
-        )
+        sorted_features = feature_report["mean_importance"].sort_values(ascending=True).index.values
         if top_n is not None and top_n > 0:
             sorted_features = sorted_features[-top_n:]
 
@@ -498,9 +477,7 @@ class PermutationImportanceResemblance(BaseResemblanceModel):
 
         for position, feature in enumerate(sorted_features):
             ax.boxplot(
-                self.iterations_results[self.iterations_results["feature"] == feature][
-                    "importance"
-                ],
+                self.iterations_results[self.iterations_results["feature"] == feature]["importance"],
                 positions=[position],
                 vert=False,
             )
@@ -531,7 +508,9 @@ class PermutationImportanceResemblance(BaseResemblanceModel):
 
 class SHAPImportanceResemblance(BaseResemblanceModel):
     """
-    This model checks for similarity of two samples. A possible use case is analysis whether train sample differs
+    This model checks for similarity of two samples.
+
+    A possible use case is analysis whether train sample differs
         from test sample, due to e.g. non-stationarity.
 
     It assigns to labels to each sample, 0 to first sample, 1 to the second. Then, It randomly selects a portion of data
@@ -571,7 +550,6 @@ class SHAPImportanceResemblance(BaseResemblanceModel):
         verbose=0,
         random_state=None,
     ):
-
         """
         Initializes the class.
 
@@ -581,7 +559,8 @@ class SHAPImportanceResemblance(BaseResemblanceModel):
 
             scoring (string or probatus.utils.Scorer, optional):
                 Metric for which the model performance is calculated. It can be either a metric name  aligned with
-                predefined [classification scorers names in sklearn](https://scikit-learn.org/stable/modules/model_evaluation.html).
+                predefined
+                [classification scorers names in sklearn](https://scikit-learn.org/stable/modules/model_evaluation.html).
                 Another option is using probatus.utils.Scorer to define a custom metric. Recommended option for this
                 class is 'roc_auc'.
 
@@ -603,7 +582,7 @@ class SHAPImportanceResemblance(BaseResemblanceModel):
                 Random state set at each round of feature elimination. If it is None, the results will not be
                 reproducible and in random search at each iteration a different hyperparameters might be tested. For
                 reproducible results set it to integer.
-        """
+        """  # noqa
         super().__init__(
             clf=clf,
             scoring=scoring,
@@ -615,9 +594,11 @@ class SHAPImportanceResemblance(BaseResemblanceModel):
 
         self.plot_title = "SHAP summary plot"
 
-    def fit(self, X1, X2, column_names=None, class_names=None):
+    def fit(self, X1, X2, column_names=None, class_names=None, **shap_kwargs):
         """
-        This function assigns to labels to each sample, 0 to first sample, 1 to the second. Then, It randomly selects a
+        This function assigns to labels to each sample, 0 to first sample, 1 to the second.
+
+        Then, It randomly selects a
             portion of data to train on. The resulting model tries to distinguish which sample does a given test row
             comes from. This provides insights on how distinguishable these samples are and which features contribute to
             that. The feature importance is calculated using SHAP feature importance.
@@ -638,16 +619,21 @@ class SHAPImportanceResemblance(BaseResemblanceModel):
                 List of class names assigned, in this case provided samples e.g. ['sample1', 'sample2']. If none, the
                 default ['First Sample', 'Second Sample'] are used.
 
+            **shap_kwargs:
+                keyword arguments passed to
+                [shap.Explainer](https://shap.readthedocs.io/en/latest/generated/shap.Explainer.html#shap.Explainer).
+                It also enables `approximate` and `check_additivity` parameters, passed while calculating SHAP values.
+                The `approximate=True` causes less accurate, but faster SHAP values calculation, while
+                `check_additivity=False` disables the additivity check inside SHAP.
+
         Returns:
             (SHAPImportanceResemblance):
                 Fitted object.
         """
         super().fit(X1=X1, X2=X2, column_names=column_names, class_names=class_names)
 
-        self.shap_values_test = shap_calc(self.clf, self.X_test, verbose=self.verbose)
-        self.report = calculate_shap_importance(
-            self.shap_values_test, self.column_names
-        )
+        self.shap_values_test = shap_calc(self.clf, self.X_test, verbose=self.verbose, **shap_kwargs)
+        self.report = calculate_shap_importance(self.shap_values_test, self.column_names)
         return self
 
     def plot(self, plot_type="bar", show=True, **summary_plot_kwargs):
