@@ -27,10 +27,11 @@ import warnings
 def shap_calc(
     model,
     X,
-    approximate=False,
     return_explainer=False,
     verbose=0,
     sample_size=100,
+    approximate=False,
+    check_additivity=True,
     **shap_kwargs,
 ):
     """
@@ -43,9 +44,6 @@ def shap_calc(
         X (pd.DataFrame or np.ndarray):
             features set.
 
-         approximate (boolean):
-            if True uses shap approximations - less accurate, but very fast.
-
         return_explainer (boolean):
             if True, returns a a tuple (shap_values, explainer).
 
@@ -57,6 +55,12 @@ def shap_calc(
             - 51 - 100 - shows other warnings and prints
             - above 100 - presents all prints and all warnings (including SHAP warnings).
 
+         approximate (boolean):
+            if True uses shap approximations - less accurate, but very fast. It applies to tree-based explainers only.
+
+         check_additivity (boolean):
+            if False SHAP will disable the additivity check for tree-based models.
+
         **shap_kwargs: kwargs of the shap.Explainer
 
     Returns:
@@ -79,13 +83,18 @@ def shap_calc(
         mask = shap.utils.sample(X, sample_size)
 
         explainer = shap.Explainer(model, masker=mask, **shap_kwargs)
-        # Calculate Shap values.
-        shap_values = explainer.shap_values(X)
+
+        # For tree-explainers allow for using check_additivity and approximate arguments
+        if isinstance(explainer, shap.explainers._tree.Tree):
+            # Calculate Shap values.
+            shap_values = explainer.shap_values(X, check_additivity=check_additivity, approximate=approximate)
+        else:
+            # Calculate Shap values.
+            shap_values = explainer.shap_values(X)
 
         if isinstance(shap_values, list) and len(shap_values) == 2:
             warnings.warn(
-                "Shap values are related to the output probabilities of class 1 for this model, instead of "
-                "log odds."
+                "Shap values are related to the output probabilities of class 1 for this model, instead of " "log odds."
             )
             shap_values = shap_values[1]
 
@@ -122,9 +131,7 @@ def shap_to_df(model, X, precalc_shap=None, **kwargs):
         return pd.DataFrame(shap_values, columns=X.columns, index=X.index)
 
     elif isinstance(X, np.ndarray) and len(X.shape) == 2:
-        return pd.DataFrame(
-            shap_values, columns=[f"col_{ix}" for ix in range(X.shape[1])]
-        )
+        return pd.DataFrame(shap_values, columns=[f"col_{ix}" for ix in range(X.shape[1])])
 
     else:
         raise NotImplementedError("X must be a dataframe or a 2d array")
@@ -149,7 +156,6 @@ def calculate_shap_importance(shap_values, columns, output_columns_suffix=""):
             Mean absolute shap values and Mean shap values of features.
 
     """
-
     # Find average shap importance for neg and pos class
     shap_abs_mean = np.mean(np.abs(shap_values), axis=0)
     shap_mean = np.mean(shap_values, axis=0)
@@ -171,8 +177,6 @@ def calculate_shap_importance(shap_values, columns, output_columns_suffix=""):
         f"mean_shap_value{output_columns_suffix}"
     ].astype(float)
 
-    importance_df = importance_df.sort_values(
-        f"mean_abs_shap_value{output_columns_suffix}", ascending=False
-    )
+    importance_df = importance_df.sort_values(f"mean_abs_shap_value{output_columns_suffix}", ascending=False)
 
     return importance_df
